update_engine: Use GetDlcsToUpdate() instead of GetInstalled()
The meaning of GetInstalled() DBus in dlcservice have changed. So we need
to get the list of DLCs that ought to be updated from the new DBus
GetDlcsToUpdate().
Also rename all dlc_module_ids to dlc_ids.
BUG=chromium:1071654
TEST=cros_workon_make --board reef --test update_engine
Cq-Depend: chromium:2157669
Change-Id: I02e450a1fd75f8b387eb8a107c9c8a32f3e01e6e
Reviewed-on: https://chromium-review.googlesource.com/c/aosp/platform/system/update_engine/+/2163441
Tested-by: Amin Hassani <ahassani@chromium.org>
Reviewed-by: Andrew Lassalle <andrewlassalle@chromium.org>
Reviewed-by: Jae Hoon Kim <kimjae@chromium.org>
Commit-Queue: Amin Hassani <ahassani@chromium.org>
diff --git a/common_service.h b/common_service.h
index 6c742a5..cfcece5 100644
--- a/common_service.h
+++ b/common_service.h
@@ -55,10 +55,10 @@
// Attempts a DLC module install operation.
// |omaha_url|: the URL to query for update.
// |dlc_module_ids|: a list of DLC module IDs.
bool AttemptInstall(brillo::ErrorPtr* error,
const std::string& omaha_url,
- const std::vector<std::string>& dlc_module_ids);
+ const std::vector<std::string>& dlc_ids);
bool AttemptRollback(brillo::ErrorPtr* error, bool in_powerwash);
@@ -55,10 +55,10 @@
// Attempts a DLC module install operation.
// |omaha_url|: the URL to query for update.
- // |dlc_module_ids|: a list of DLC module IDs.
+ // |dlc_ids|: a list of DLC module IDs.
bool AttemptInstall(brillo::ErrorPtr* error,
const std::string& omaha_url,